@@ -1,7 +1,9 @@
 from .students import Student
 from .telegram import Telegram
+from .tokens import Token
 
 __all__ = (
     "Student",
     "Telegram",
+    "Token",
 )
