@@ -206,7 +206,7 @@ class Dialog:
 
     async def __normal_start(self) -> AsyncAdventure:
         """The /start command, called without arguments."""
-        msg: telethon.tl.custom.Message = yield
+        _: telethon.tl.custom.Message = yield
 
         await self.__message(
             f'👋 Ciao! Sono Thor, il bot-moderatore di Unimore Informatica.\n'
@@ -219,7 +219,7 @@ class Dialog:
 
     async def __deeplink_start(self, payload: str) -> AsyncAdventure:
         """The /start command, called with deep-linked arguments."""
-        msg: telethon.tl.custom.Message = yield
+        _: telethon.tl.custom.Message = yield
 
         try:
             opcode, data = dl.decode(payload)
@@ -245,7 +245,6 @@ class Dialog:
 
         from_user = await msg.get_sender()
 
-        tg: Telegram = self.session.query(Telegram).filter_by(id=from_user.id).one_or_none()
         st: Student = self.session.query(Student).filter_by(email_prefix=email_prefix).one()
 
         # Ask for confirmation
@@ -261,11 +260,12 @@ class Dialog:
 
         # Ask for privacy mode
         choice = yield Keyboard(
-            message="📝 Vuoi permettere agli altri studenti verificati di visualizzare il tuo <b>vero nome</b> e la tua "
-                    "<b>email istituzionale</b> attraverso il comando /whois?\n\n"
+            message="📝 Vuoi permettere agli altri studenti verificati di associare il tuo <b>vero nome</b> e la tua "
+                    "<b>email istituzionale</b> al tuo <b>account Telegram</b>?"
+                    "\n\n"
                     "(Gli amministratori del gruppo vi avranno comunque accesso, e potrai cambiare idea in qualsiasi "
                     "momento con il comando /settings.)",
-            choices=[["👤 Nascondi.", "📱 Mostra!"]]
+            choices=[["👤 Nascondi.", "📱 Mostra!"]],
         )
         st.privacy = choice.message == "👤 Nascondi."
 
@@ -306,8 +306,9 @@ class Dialog:
 
         # Ask for privacy mode
         choice = yield Keyboard(
-            message="📝 Vuoi permettere agli altri studenti verificati di visualizzare il tuo <b>vero nome</b> e la tua "
-                    "<b>email istituzionale</b> attraverso il comando /whois?\n\n"
+            message="📝 Vuoi permettere agli altri studenti verificati di associare il tuo <b>vero nome</b> e la tua "
+                    "<b>email istituzionale</b> al tuo <b>account Telegram</b>?"
+                    "\n\n"
                     "(Gli amministratori del gruppo vi avranno comunque accesso, e potrai cambiare idea in qualsiasi "
                     "momento con il comando /settings.)",
             choices=[["👤 Nascondi.", "📱 Mostra!"]],
@@ -324,7 +325,7 @@ class Dialog:
         """The /whois command, used to fetch information about a certain student or Telegram account."""
         msg: telethon.tl.custom.Message = yield
 
-        cmd, *args = msg.message.split(" ", 1)
+        _, *args = msg.message.split(" ", 1)
         args = " ".join(args)
 
         from_user = await msg.get_sender()
@@ -343,22 +344,30 @@ class Dialog:
         elif " " in args:
             yield self.__whois_real_name(name=args, admin=from_tg.is_admin)
 
+        # Telegram username
         elif args.startswith("@"):
             username = args.lstrip("@")
             yield self.__whois_username(username=username, admin=from_tg.is_admin)
 
-        # TODO: Match telegram mentions
-        # TODO: Match telegram name
+        # Telegram id
+        elif args.startswith("tg:"):
+            _, tg_id = args.split(":", 1)
+            try:
+                tg_id = int(tg_id)
+            except ValueError:
+                await self.__message("⚠️ L'ID Telegram che hai specificato non sembra essere valido.")
+                return
+            else:
+                yield self.__whois_tg_id(tg_id=tg_id, admin=from_tg.is_admin)
 
         await self.__message(
             "⚠️ Non hai specificato correttamente cosa cercare.\n"
             "\n"
-            "Puoi specificare un'username Telegram, un nome e cognome o un'email.\n"
+            "Puoi specificare un'username o un id Telegram, un nome e cognome o un'email.\n"
             "<code>/whois Stefano Pigozzi</code>\n"
             "<code>/whois @Steffo</code>\n"
-            "<code>/whois 256895@studenti.unimore.it</code>\n"
-            "\n"
-            "🚧 La funzionalità di ricerca tramite name-mention di Telegram non è ancora stata implementata."
+            "<code>/whois tg:25167391</code>\n"
+            "<code>/whois 256895@studenti.unimore.it</code>"
         )
 
     async def __whois_email(self, email_prefix: str, admin: bool):
@@ -418,3 +427,17 @@ class Dialog:
             await self.__message(tg.st.whois_message())
         else:
             await self.__message(tg.st.whois())
+
+    async def __whois_tg_id(self, tg_id: int, admin: bool) -> AsyncAdventure:
+        """The /whois command, called with a Telegram id."""
+        msg: telethon.tl.custom.Message = yield
+
+        tg: Optional[Telegram] = self.session.query(Telegram).get(tg_id)
+        if tg is None:
+            await self.__message("⚠️ Nessuno studente trovato.")
+            return
+
+        if admin and msg.is_private:
+            await self.__message(tg.st.whois_message())
+        else:
+            await self.__message(tg.st.whois())
