@@ -17,7 +17,7 @@ app = flask.Flask(__name__)
 app.config.update(**os.environ)
 
 # noinspection PyArgumentEqualDefault
-reverse_proxy_app = werkzeug.middleware.proxy_fix.ProxyFix(app=app, x_for=1, x_proto=0, x_host=1, x_port=0, x_prefix=0)
+reverse_proxy_app = werkzeug.middleware.proxy_fix.ProxyFix(app=app, x_for=1, x_proto=1, x_host=1, x_port=0, x_prefix=0)
 
 db = flask_sqlalchemy.SQLAlchemy(app=app, metadata=Base.metadata)
 db.create_all()
@@ -144,5 +144,9 @@ def api_whois(token: str, tg_id: int):
     }), 200
 
 
-if __name__ == "__main__":
+def main():
     app.run()
+
+
+if __name__ == "__main__":
+    main()
